@@ -275,7 +275,7 @@ void App_WithDoc::on_menu_file_saveas()
     if(bUseThisFileUri)
     {
       m_pDocument->set_file_uri(file_uri, true); //true = enforce file extension
-      bool bTest  = m_pDocument->save();
+      const bool bTest = m_pDocument->save();
 
       if(!bTest)
       {
