@@ -170,7 +170,7 @@ bool Document::save()
   if(m_pView)
     m_pView->save_to_document();
 
-  bool bTest = save_before(); //This could be overridden.
+  const bool bTest = save_before(); //This could be overridden.
   if(bTest)
     return write_to_disk();
 
